@@ -50,29 +50,35 @@ class Logger(object):
             return
         makeFilePath(filename)
 
-    def d(self, *args):
+    def d(self, *args, **kwargs):
         msg = ' '.join(['%s'%i for i in args])
-        self.logger.debug(msg, stacklevel=2)
+        stacklevel = kwargs.get('stacklevel', 2)
+        self.logger.debug(msg, stacklevel=stacklevel)
 
-    def i(self, *args):
+    def i(self, *args, **kwargs):
         msg = ' '.join(['%s'%i for i in args])
-        self.logger.info(msg, stacklevel=2)
+        stacklevel = kwargs.get('stacklevel', 2)
+        self.logger.info(msg, stacklevel=stacklevel)
 
-    def w(self, *args):
+    def w(self, *args, **kwargs):
         msg = ' '.join(['%s'%i for i in args])
-        self.logger.warning(msg, stacklevel=2)
+        stacklevel = kwargs.get('stacklevel', 2)
+        self.logger.warning(msg, stacklevel=stacklevel)
 
-    def e(self, *args):
+    def e(self, *args, **kwargs):
         msg = ' '.join(['%s'%i for i in args])
-        self.logger.error(msg, stacklevel=2)
+        stacklevel = kwargs.get('stacklevel', 2)
+        self.logger.error(msg, stacklevel=stacklevel)
 
-    def exc(self, *args):
+    def exc(self, *args, **kwargs):
         msg = ' '.join(['%s'%i for i in args])
-        self.logger.exception(msg, stacklevel=3)
+        stacklevel = kwargs.get('stacklevel', 3)
+        self.logger.exception(msg, stacklevel=stacklevel)
 
-    def x(self, *args):
+    def x(self, *args, **kwargs):
         msg = ' '.join(['%s'%i for i in args])
-        self.logger.critical(msg, stacklevel=2)
+        stacklevel = kwargs.get('stacklevel', 2)
+        self.logger.critical(msg, stacklevel=stacklevel)
 
 
 def makeFilePath(path):
